@@ -7,7 +7,7 @@
 
    Author: Ilan Schnell
 */
-#define BITARRAY_VERSION  "1.5.0"
+#define BITARRAY_VERSION  "1.5.1"
 
 #define PY_SSIZE_T_CLEAN
 #include "Python.h"
@@ -337,27 +337,31 @@ invert(bitarrayobject *self)
         self->ob_item[i] = ~self->ob_item[i];
 }
 
-/* repeat self 'count' times (negative 'count' is treated as 0) */
+/* repeat self n times (negative n is treated as 0) */
 static int
-repeat(bitarrayobject *self, Py_ssize_t count)
+repeat(bitarrayobject *self, Py_ssize_t n)
 {
     const Py_ssize_t nbits = self->nbits;
     Py_ssize_t i;
 
-    if (count < 0)
-        count = 0;
+    if (nbits == 0 || n == 1)   /* nothing to do */
+        return 0;
 
-    if (count > 0 && nbits > PY_SSIZE_T_MAX / count) {
+    if (n <= 0)                 /* clear */
+        return resize(self, 0);
+
+    assert(n > 1 && nbits > 0);
+    if (nbits > PY_SSIZE_T_MAX / n) {
         PyErr_Format(PyExc_OverflowError,
                      "cannot repeat bitarray (of size %zd) %zd times",
-                     nbits, count);
+                     nbits, n);
         return -1;
     }
 
-    if (resize(self, count * nbits) < 0)
+    if (resize(self, n * nbits) < 0)
         return -1;
 
-    for (i = 1; i < count; i++)
+    for (i = 1; i < n; i++)
         copy_n(self, i * nbits, self, 0, nbits);
 
     return 0;
@@ -717,7 +721,7 @@ unpack(bitarrayobject *self, char zero, char one, const char *fmt)
 #define IS_INT_OR_BOOL(x)  (PyBool_Check(x) || PyLong_Check(x))
 #else  /* Py 2 */
 #define IS_INT_OR_BOOL(x)  (PyBool_Check(x) || PyInt_Check(x) || \
-                                               PyLong_Check(x))
+                            PyLong_Check(x))
 #endif
 
 /* given an PyLong (which must be 0 or 1), or a PyBool, return 0 or 1,
@@ -772,13 +776,19 @@ normalize_index(Py_ssize_t n, Py_ssize_t *i)
 static PyObject *
 bitarray_length(bitarrayobject *self)
 {
+    if (PyErr_WarnEx(PyExc_DeprecationWarning,
+                     "self.length() has been deprecated since 1.5.1, "
+                     "use len(self) instead", 1) < 0)
+        return NULL;
+
     return PyLong_FromLongLong(self->nbits);
 }
 
 PyDoc_STRVAR(length_doc,
 "length() -> int\n\
 \n\
-Return the length - a.length() is the same as len(a).");
+Return the length - a.length() is the same as len(a).\n\
+Deprecated since 1.5.1, use len().");
 
 
 static PyObject *
